<?php
/**
* Homepage Settings.
*
* @package Dhimay
*/

$dhimay_default = dhimay_get_default_theme_options();
$dhimay_post_category_list = dhimay_post_category_list();

$wp_customize->add_panel( 'homepage_option_panel',
	array(
		'title'      => esc_html__( 'Homepage Options', 'dhimay' ),
		'priority'   => 150,
		'capability' => 'edit_theme_options',
	)
);


// Recent Release
$wp_customize->add_section( 'homepage_recent_release_block',
    array(
    'title'      => esc_html__( 'Recent Release Block', 'dhimay' ),
    'priority'   => 200,
    'capability' => 'edit_theme_options',
    'panel'      => 'homepage_option_panel',
    )
);

$wp_customize->add_setting('enable_recent_release_block',
    array(
        'default' => $dhimay_default['enable_recent_release_block'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'dhimay_sanitize_checkbox',
    )
);
$wp_customize->add_control('enable_recent_release_block',
    array(
        'label' => esc_html__('Enable Section', 'dhimay'),
        'section' => 'homepage_recent_release_block',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting( 'recent_release_cat',
    array(
    'default'           => '',
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'dhimay_sanitize_select',
    )
);
$wp_customize->add_control( 'recent_release_cat',
    array(
    'label'       => esc_html__( 'Recent Release Category', 'dhimay' ),
    'section'     => 'homepage_recent_release_block',
    'type'        => 'select',
    'choices'     => $dhimay_post_category_list,
    )
);


$wp_customize->add_section( 'homepage_event_block',
	array(
	'title'      => esc_html__( 'Upcoming Events Block', 'dhimay' ),
	'priority'   => 200,
	'capability' => 'edit_theme_options',
	'panel'      => 'homepage_option_panel',
	)
);

$wp_customize->add_setting('enable_event_block',
    array(
        'default' => $dhimay_default['enable_event_block'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'dhimay_sanitize_checkbox',
    )
);
$wp_customize->add_control('enable_event_block',
    array(
        'label' => esc_html__('Enable Section', 'dhimay'),
        'section' => 'homepage_event_block',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting( 'events_block_title',
	array(
	'default'           => $dhimay_default['events_block_title'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'events_block_title',
	array(
	'label'    => __( 'Section Title', 'dhimay' ),
	'section'  => 'homepage_event_block',
	'type'     => 'text',
	)
);


$wp_customize->add_setting( 'events_block_shortcode',
	array(
	'default'           => $dhimay_default['events_block_shortcode'],
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'events_block_shortcode',
	array(
	'label'    => __( 'Events Shortcode', 'dhimay' ),
	'section'  => 'homepage_event_block',
	'type'     => 'text',
	)
);

// Setting event_section_bg_image.
$wp_customize->add_setting('event_section_bg_image',
	array(
		'default'           => $dhimay_default['event_section_bg_image'],
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'dhimay_sanitize_image',
	)
);
$wp_customize->add_control(
	new WP_Customize_Image_Control($wp_customize, 'event_section_bg_image',
		array(
			'label'       => esc_html__('Section Background Image', 'dhimay'),
			'section'     => 'homepage_event_block',
		)
	)
);




// Featured Page
$wp_customize->add_section( 'homepage_featured_page_block',
	array(
	'title'      => esc_html__( 'Featured Page Block', 'dhimay' ),
	'priority'   => 200,
	'capability' => 'edit_theme_options',
	'panel'      => 'homepage_option_panel',
	)
);

$wp_customize->add_setting('enable_featured_page_block',
    array(
        'default' => $dhimay_default['enable_featured_page_block'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'dhimay_sanitize_checkbox',
    )
);
$wp_customize->add_control('enable_featured_page_block',
    array(
        'label' => esc_html__('Enable Section', 'dhimay'),
        'section' => 'homepage_featured_page_block',
        'type' => 'checkbox',
    )
);


for ( $i=1; $i <= 5 ; $i++ ) {
        $wp_customize->add_setting( 'select_featured_page_'. $i, array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'dhimay_sanitize_dropdown_pages',
        ) );

        $wp_customize->add_control( 'select_featured_page_'. $i, array(
            'input_attrs'       => array(
                'style'           => 'width: 50px;'
                ),
            'label'             => __( 'Featured Page', 'dhimay' ) . ' - ' . $i ,
            'section'           => 'homepage_featured_page_block',
            'type'        		=> 'dropdown-pages',
            )
        );
    }



// video CTA
$wp_customize->add_section( 'homepage_video_cta_block',
	array(
	'title'      => esc_html__( 'Video CTA Block', 'dhimay' ),
	'priority'   => 200,
	'capability' => 'edit_theme_options',
	'panel'      => 'homepage_option_panel',
	)
);


$wp_customize->add_setting('enable_video_cta_block',
    array(
        'default' => $dhimay_default['enable_video_cta_block'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'dhimay_sanitize_checkbox',
    )
);
$wp_customize->add_control('enable_video_cta_block',
    array(
        'label' => esc_html__('Enable Section', 'dhimay'),
        'section' => 'homepage_video_cta_block',
        'type' => 'checkbox',
    )
);


$wp_customize->add_setting('vidoe_cta_bg_image',
    array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )
);
$wp_customize->add_control( new WP_Customize_Image_Control(
    $wp_customize,
    'vidoe_cta_bg_image',
        array(
            'label'      => esc_html__( 'Video CTA Background Image', 'dhimay' ),
            'section'    => 'homepage_video_cta_block',
        )
    )
);

$wp_customize->add_setting( 'video_cta_select_page', array(
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'dhimay_sanitize_dropdown_pages',
) );

$wp_customize->add_control( 'video_cta_select_page', array(
    'input_attrs'       => array(
        'style'           => 'width: 50px;'
        ),
    'label'             => __( 'Video Featured Page', 'dhimay' ) ,
    'section'           => 'homepage_video_cta_block',
    'type'        		=> 'dropdown-pages',
    'allow_addition' => true,
    )
);

$wp_customize->add_setting( 'vidoe_cta_button_text',
    array(
    'default'           => $dhimay_default['vidoe_cta_button_text'],
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'vidoe_cta_button_text',
    array(
    'label'       => esc_html__( 'Video CTa Button Text', 'dhimay' ),
    'section'     => 'homepage_video_cta_block',
    'type'        => 'text',
    )
);

$wp_customize->add_setting( 'video_cta_button_link',
    array(
    'default'           => '',
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control( 'video_cta_button_link',
    array(
    'label'       => esc_html__( 'Video CTA Button Link', 'dhimay' ),
    'section'     => 'homepage_video_cta_block',
    'type'        => 'text',
    )
);
