<?php
if (!function_exists('dhimay_event_block')):
    /**
     * Event Blog
     *
     * @since Dhimay 1.0.0
     *
     */
    function dhimay_event_block()
    {
        $dhimay_default = dhimay_get_default_theme_options();
        if (1 != get_theme_mod('enable_event_block')) {
            return null;
        } 
        $events_block_title = get_theme_mod( 'events_block_title',$dhimay_default['events_block_title'] );
        $events_block_shortcode = get_theme_mod( 'events_block_shortcode',$dhimay_default['events_block_shortcode'] );
        $event_section_bg_image = get_theme_mod( 'event_section_bg_image',$dhimay_default['event_section_bg_image'] );
        ?>
        
        <div class="theme-blocks theme-blocks-event data-bg data-bg-fixed" data-background='<?php echo esc_url($event_section_bg_image); ?>'>
            <div class="theme-main-event">
                <?php if ($events_block_title) { ?>
                <div class="theme-panel-header">
                    <div class="theme-panel-title">
                        <?php echo esc_html($events_block_title); ?>
                    </div>
                </div>
            <?php } ?>
            <?php if ($events_block_shortcode) { ?>
                <div class="theme-panel-body">
                    <div class="wrapper-smaller">
                        <div class="wrapper-inner">
                            <div class="column column-12">
                                <?php echo do_shortcode($events_block_shortcode); ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php }?>
            </div>
        </div>

    <?php }
endif;
add_action('dhimay_action_event_block', 'dhimay_event_block', 20);


if (!function_exists('dhimay_featured_page_block')):
    /**
     * Event Blog
     *
     * @since Dhimay 1.0.0
     *
     */
    function dhimay_featured_page_block()
    {
        $dhimay_default = dhimay_get_default_theme_options();
        if (1 != get_theme_mod('enable_featured_page_block')) {
            return null;
        } 
        $dhimay_featured_page_array = array();
        for ($i = 1; $i <= 5; $i++) {
            $dhimay_featured_page_list = get_theme_mod('select_featured_page_' . $i);
            if (!empty($dhimay_featured_page_list)) {
                $dhimay_featured_page_array[] = absint($dhimay_featured_page_list);
            }
        }
        // Bail if no valid pages are selected.
        if (empty($dhimay_featured_page_array)) {
            return;
        }
        $qargs = array(
            'posts_per_page' => 5,
            'post_type' => 'page',
            'post__in' => $dhimay_featured_page_array,
        );
        $page_tabs = '';
        ?>


        <div class="theme-block theme-tab-block">
            <div class="wrapper-small">
                <div class="wrapper-inner">
                    <div class="column column-12">
                        <div class="theme-tab-container">
                    <div class="tab-content-section">
                        <?php
                        $i = 1;
                        $dhimay_featured_page_query = new WP_Query($qargs);
                        if ($dhimay_featured_page_query->have_posts()) :
                            while ($dhimay_featured_page_query->have_posts()) : $dhimay_featured_page_query->the_post();
                                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium-large');
                                $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                <div id="tab<?php echo($i); ?>" class="tab-content">
                                    <div class="theme-article-container">
                                        <div class="wrapper-inner ghost-wrapper-inner">
                                            <div class="column column-7 column-om-12">
                                                <div class="theme-grid-left">
                                                <div class="theme-article-image">
                                                    <?php if ($featured_image) { ?>
                                                        <div class="data-bg data-bg-large"
                                                            data-background='<?php echo esc_url($featured_image); ?>'></div>
                                                    <?php } ?>
                                                </div>
                                             </div>
                                            </div>

                                        <div class="column column-5 column-om-12">
                                            <div class="theme-grid-right">
                                            <div class="theme-article-detail">
                                                <header class="theme-article-header">
                                                    <h3 class="entry-title entry-title-big">
                                                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                    </h3>
                                                </header>

                                                <div class="theme-article-content">
                                                    <div class="theme-article-excerpt">
                                                        <?php the_excerpt(); ?>
                                                    </div>

                                                    <a href="<?php the_permalink(); ?>"
                                                       class="entry-meta entry-meta-link">
                                                        <div class="meta-link-content">
                                                            <span><?php echo esc_html__('Read More', 'dhimay') ?>  </span>
                                                            <svg xmlns="http://www.w3.org/2000/svg" width="20"
                                                                 height="20" viewBox="0 0 20 20">
                                                                <path fill="currentColor"
                                                                      d="M16.172 9l-6.071-6.071 1.414-1.414 8.485 8.485-8.485 8.485-1.414-1.414 6.071-6.071h-16.172v-2z"></path>
                                                            </svg>
                                                        </div>
                                                    </a>
                                                </div>
                                            </div>
                                        </div>
                                        </div>
                                        </div>
                                    </div>
                                </div>
                                <?php $page_tabs .= '<li><a href="" data-id="tab' . esc_html($i) . '">';
                                $page_tabs .= esc_html(wp_trim_words(get_the_title()));
                                $page_tabs .= '</a></li>'; ?>
                                <?php $i++;
                            endwhile;
                            wp_reset_postdata();
                        endif; ?>
                    </div>
                    <ul class='theme-tabs'>
                        <?php echo $page_tabs; ?>
                    </ul>
                </div>
                    </div>
                </div>
            </div>
        </div>

    <?php }
endif;
add_action('dhimay_action_featured_page_block', 'dhimay_featured_page_block', 20);


if (!function_exists('dhimay_recent_release_block')):
    /**
     * Event Blog
     *
     * @since Dhimay 1.0.0
     *
     */
    function dhimay_recent_release_block()
    { 
        $dhimay_default = dhimay_get_default_theme_options();
        if (1 != get_theme_mod('enable_recent_release_block')) {
            return null;
        }
        $recent_release_cat = esc_html(get_theme_mod('recent_release_cat'));

        $dhimay_recent_release_query = new WP_Query( array(
            'post_type' => 'post',
            'category_name' => esc_html($recent_release_cat),
            'ignore_sticky_posts' => true,
            'posts_per_page' => 6,
        ));
        if( $dhimay_recent_release_query->have_posts() ): ?>
        <div class="theme-blocks theme-blocks-slider">
            <div class="wrapper-small">
                <div class="wrapper-inner">
                    <div class="column column-12">
                        <div class="theme-slider-container">
                            <div class="theme-main-slider theme-slick-space">
                                <?php
                                while ($dhimay_recent_release_query->have_posts()):
                                    $dhimay_recent_release_query->the_post(); 

                                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium-large');
                                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : '';?>
                                    <div class="theme-slider-item">
                                        <div class="theme-article-container">
                                            <div class="wrapper-inner wrapper-inner-center">
                                                <div class="column column-5 column-xxs-12">
                                                    <div class="theme-article-image">
                                                        <div class="data-bg data-bg-big" data-background="<?php echo esc_url($featured_image); ?>" ></div>
                                                    </div>
                                                </div>


                                                <div class="column column-7 column-xxs-12">
                                                    <div class="theme-article-detail">
                                                        <header class="theme-article-header">
                                                            <div class="entry-meta-top">
                                                                <div class="entry-meta entry-meta-date">
                                                                    <?php
                                                                    dhimay_posted_by();
                                                                    dhimay_posted_on();
                                                                    ?>
                                                                </div>
                                                            </div>

                                                            <h3 class="entry-title entry-title-large">
                                                                <a href="<?php the_permalink(); ?>">
                                                                    <?php the_title(); ?>
                                                                </a>
                                                            </h3>
                                                            <div class="twp-content-audio">
                                                                <?php
                                                                $post_blocks = parse_blocks(get_the_content());
                                                                if ($post_blocks) {
                                                                    foreach ($post_blocks as $post_block) {
                                                                        if (isset($post_block['blockName']) &&
                                                                            isset($post_block['innerHTML']) &&
                                                                            $post_block['blockName'] == 'core/audio') {
                                                                            echo '<div class="entry-audio">';
                                                                            echo wp_kses_post($post_block['innerHTML']);
                                                                            echo '</div>';
                                                                            break;
                                                                        }
                                                                    }
                                                                } ?>
                                                            </div>

                                                        </header>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                <?php
                                endwhile; ?>
                            </div>

                            <div class="theme-slider-button">
                                <div class="slider-btn slider-btn-prev">
                                    <svg xmlns="http://www.w3.org/2000/svg" aria-hidden="true" role="img" width="1em" height="1em" preserveAspectRatio="xMidYMid meet" viewBox="0 0 20 20"><path fill="currentColor" d="m14 5l-5 5l5 5l-1 2l-7-7l7-7z"/></svg>
                                </div>
                                <div class="slider-btn slider-btn-next">
                                    <svg xmlns="http://www.w3.org/2000/svg" aria-hidden="true" role="img" width="1em" height="1em" preserveAspectRatio="xMidYMid meet" viewBox="0 0 20 20"><path fill="currentColor" d="m6 15l5-5l-5-5l1-2l7 7l-7 7z"/></svg>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>  
        <?php 
        wp_reset_postdata();
        endif; ?>
    <?php }
endif;
add_action('dhimay_action_recent_release_block', 'dhimay_recent_release_block', 20);


if (!function_exists('dhimay_video_cta_page_block')):
    /**
     * Event Blog
     *
     * @since Dhimay 1.0.0
     *
     */
    function dhimay_video_cta_page_block()
    {
        $dhimay_default = dhimay_get_default_theme_options();
        if (1 != get_theme_mod('enable_video_cta_block')) {
            return null;
        } 
        $dhimay_video_cta_page = get_theme_mod( 'video_cta_select_page' );
        $vidoe_cta_bg_image = get_theme_mod( 'vidoe_cta_bg_image');
        $vidoe_cta_button_text = get_theme_mod( 'vidoe_cta_button_text',$dhimay_default['vidoe_cta_button_text'] );
        $video_cta_button_link = get_theme_mod( 'video_cta_button_link');


        // Bail if no valid pages are selected.
        if (empty($dhimay_video_cta_page)) {
            return;
        }
        $qargs = array(
            'posts_per_page' => 1,
            'post_type' => 'page',
            'page_id' => $dhimay_video_cta_page,
        );
        ?>
        <!-- video cta  -->
        <div class="theme-blocks theme-video-cta data-bg data-bg-fixed" data-background = '<?php echo esc_url($vidoe_cta_bg_image);?>'>
            <div class="video-cta-container">
                <div class="theme-article-container">
                    <div class="wrapper-small">
                        <div class="wrapper-inner wrapper-inner-center">
                                <?php 
                        $dhimay_video_cta_query = new WP_Query($qargs);
                        if ($dhimay_video_cta_query->have_posts()) :
                            while ($dhimay_video_cta_query->have_posts()) : $dhimay_video_cta_query->the_post(); 
                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium-large');
                            $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>
                                    <div class="column column-6 column-om-12">
                                        <div class="theme-article-detail">
                                            <header class="theme-article-header">
                                                <h3 class="entry-title entry-title-large">
                                                    <a href="<?php the_permalink(); ?>"><?php the_title();?></a>
                                                </h3>

                                                <div class="entry-meta-bottom">
                                                    <?php
                                                    dhimay_posted_by();
                                                    dhimay_posted_on();
                                                    ?>
                                                </div>
                                            </header>

                                            <div class="theme-article-content">
                                                <div class="theme-article-excerpt">
                                                    <?php the_excerpt();?>
                                                </div>
                                                <a href="<?php echo esc_url($video_cta_button_link); ?>" class="entry-meta entry-meta-link"> 
                                                    <div class="meta-link-content">
                                                        <span><?php echo esc_html($vidoe_cta_button_text); ?></span>
                                                    <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 20 20"><path fill="currentColor" d="M16.172 9l-6.071-6.071 1.414-1.414 8.485 8.485-8.485 8.485-1.414-1.414 6.071-6.071h-16.172v-2z"></path></svg>
                                                    </div>
                                                </a>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="column column-1 hidden-xs-screen"></div>

                                    <?php $content = apply_filters('the_content', get_the_content());
                                    $video = false;
                                    // Only get video from the content if a playlist isn't present.
                                    if (false === strpos($content, 'wp-playlist-script')) {
                                        $video = get_media_embedded_in_content($content, array('video', 'object', 'embed', 'iframe'));
                                    }
                                    if (!empty($video)) {
                                        $twp_aspect_ratio = get_post_meta(get_the_ID(), 'twp_aspect_ratio', true);
                                        if ($twp_aspect_ratio == '') {
                                            $twp_aspect_ratio = 'default';
                                        } ?>

                                        <div class="column column-5 column-om-12">
                                            <div class="twp-content-video theme-image-border">
                                                <?php
                                                foreach ($video as $video_html) { ?>
                                                    <div class="entry-video theme-ratio-<?php echo esc_attr($twp_aspect_ratio); ?>">
                                                        <div class="twp-video-control-buttons hide-no-js">
                                                            <button attr-id="video-id-<?php echo absint(get_the_ID()); ?>" class="theme-video-control theme-action-control twp-pause-play pause">
                                                                <span class="action-control-trigger">
                                                                    <span class="twp-video-control-action">
                                                                        <?php dhimay_the_theme_svg('pause'); ?>
                                                                    </span>
                                                                    <span class="screen-reader-text">
                                                                        <?php esc_html_e('Pause', 'dhimay'); ?>
                                                                    </span>
                                                                </span>
                                                            </button>
                                                            <button attr-id="video-id-<?php echo absint(get_the_ID()); ?>" class="theme-video-control theme-action-control twp-mute-unmute unmute">
                                                                <span class="action-control-trigger">
                                                                    <span class="twp-video-control-action">
                                                                        <?php dhimay_the_theme_svg('mute'); ?>
                                                                    </span>
                                                                    <span class="screen-reader-text">
                                                                        <?php esc_html_e('Unmute', 'dhimay'); ?>
                                                                    </span>
                                                                </span>
                                                            </button>
                                                        </div>
                                                        <div class="theme-video-panel video-main-wraper" data-id="video-id-<?php echo absint(get_the_ID()); ?>">
                                                            <?php echo dhimay_iframe_escape($video_html); ?>
                                                        </div>
                                                    </div>
                                                    <?php
                                                    break;
                                                } ?>
                                            </div>
                                        </div>
                                        <?php
                                    } else {
                                        if (has_post_thumbnail()) {
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                            $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                                <div class="column column-5 column-om-12">
                                                    <div class="theme-article-image theme-image-border">
                                                        <div class="data-bg data-bg-big" data-background= '<?php echo esc_url($featured_image); ?>'></div>
                                                    </div>
                                                </div>
                                            <?php
                                        }
                                    } ?>

                            <?php
                            endwhile;
                            wp_reset_postdata();
                        endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- video cta ends  -->

    <?php }
endif;
add_action('dhimay_action_video_cta_block', 'dhimay_video_cta_page_block', 20);
